pub struct Driver<E, DP, P>where
E: Executor + Send + Sync + Debug,
DP: DriverPipeline<P> + Send + Sync + Debug,
P: Pipeline + SignalReceiver + Send + Sync + Debug,{
pub cursor: Arc<RwLock<PipelineCursor>>,
pub executor: E,
pub pipeline: DP,
pub safe_head_artifacts: Option<(BlockBuildingOutcome, Vec<Bytes>)>,
/* private fields */
}Expand description
The Rollup Driver entrypoint.
Fields
cursor: Arc<RwLock<PipelineCursor>>Cursor to keep track of the L2 tip
executor: EThe Executor.
pipeline: DPA pipeline abstraction.
safe_head_artifacts: Option<(BlockBuildingOutcome, Vec<Bytes>)>The safe head’s execution artifacts + Transactions
Implementations
Sourceimpl<E, DP, P> Driver<E, DP, P>
impl<E, DP, P> Driver<E, DP, P>
Sourcepub const fn new(
cursor: Arc<RwLock<PipelineCursor>>,
executor: E,
pipeline: DP,
) -> Self
pub const fn new( cursor: Arc<RwLock<PipelineCursor>>, executor: E, pipeline: DP, ) -> Self
Creates a new Driver.
Sourcepub async fn wait_for_executor(&mut self)
pub async fn wait_for_executor(&mut self)
Waits until the executor is ready.
Sourcepub async fn advance_to_target(
&mut self,
cfg: &RollupConfig,
target: Option<u64>,
) -> DriverResult<(L2BlockInfo, B256), E::Error>
pub async fn advance_to_target( &mut self, cfg: &RollupConfig, target: Option<u64>, ) -> DriverResult<(L2BlockInfo, B256), E::Error>
Advances the derivation pipeline to the target block number.
Takes
cfg: The rollup configuration.target: The target block number.
Returns
Ok((l2_safe_head, output_root))- A tuple containing theL2BlockInfoof the produced block and the output root.Err(e)- An error if the block could not be produced.