kona_driver

Struct Driver

pub struct Driver<E, DP, P>{
    pub pipeline: DP,
    pub cursor: PipelineCursor,
    pub executor: E,
    /* private fields */
}
The Rollup Driver entrypoint.

Fields

pipeline: DP

A pipeline abstraction.

cursor: PipelineCursor

Cursor to keep track of the L2 tip

executor: E

The Executor.

Implementations

Source

impl<E, DP, P> Driver<E, DP, P>

pub const fn new(cursor: PipelineCursor, executor: E, pipeline: DP) -> Self

Creates a new Driver.

pub async fn wait_for_executor(&mut self)

Waits until the executor is ready.

pub async fn advance_to_target( &mut self, cfg: &RollupConfig, target: Option<u64>, ) -> DriverResult<(u64, B256), E::Error>

Advances the derivation pipeline to the target block number.

Takes
  • cfg: The rollup configuration.
  • target: The target block number.
Returns
  • Ok((number, output_root)) - A tuple containing the number of the produced block and the output root.
  • Err(e) - An error if the block could not be produced.